==> customer-link-project-api-0.0.19-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app89420/vo/MatchVO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app89420.vo;

public class MatchVO {

    /**
     * 比赛时间
     */
    private long matchTime;

    /**
     * 主场球队
     */
    private String homeTeam;

    /**
     * 客场球队
     */
    private String awayTeam;

    /**
     * 主场国家图片
     */
    private String homeTeamIcon;

    /**
     * 客场国家图片
     */
    private String awayTeamIcon;

    /**
     * 主场分数
     */
    private Integer homeScore;

    /**
     * 客场分数
     */
    private Integer awayScore;

    /**
     * 比赛状态 0-未完赛 1-已完赛
     */
    private Integer state;

    /**
     * 阶段id
     * 50897 分组赛
     * 50898 1/8决赛
     * 50899 1/4決賽
     * 50900 半決賽
     * 50901 季軍賽
     * 50902 決賽
     */
    private Integer stageId;

    /**
     * 组数
     */
    private Integer groupNum;

    /**
     * 轮次数
     */
    private Integer roundNum;

    /**
     * 比赛id
     */
    private String matchId;

    public String getMatchId() {
        return matchId;
    }

    public void setMatchId(String matchId) {
        this.matchId = matchId;
    }

    public Integer getStageId() {
        return stageId;
    }

    public void setStageId(Integer stageId) {
        this.stageId = stageId;
    }

    public Integer getGroupNum() {
        return groupNum;
    }

    public void setGroupNum(Integer groupNum) {
        this.groupNum = groupNum;
    }

    public Integer getRoundNum() {
        return roundNum;
    }

    public void setRoundNum(Integer roundNum) {
        this.roundNum = roundNum;
    }

    public String getHomeTeamIcon() {
        return homeTeamIcon;
    }

    public void setHomeTeamIcon(String homeTeamIcon) {
        this.homeTeamIcon = homeTeamIcon;
    }

    public String getAwayTeamIcon() {
        return awayTeamIcon;
    }

    public void setAwayTeamIcon(String awayTeamIcon) {
        this.awayTeamIcon = awayTeamIcon;
    }

    public Integer getHomeScore() {
        return homeScore;
    }

    public void setHomeScore(Integer homeScore) {
        this.homeScore = homeScore;
    }

    public Integer getAwayScore() {
        return awayScore;
    }

    public void setAwayScore(Integer awayScore) {
        this.awayScore = awayScore;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public long getMatchTime() {
        return matchTime;
    }

    public void setMatchTime(long matchTime) {
        this.matchTime = matchTime;
    }

    public String getHomeTeam() {
        return homeTeam;
    }

    public void setHomeTeam(String homeTeam) {
        this.homeTeam = homeTeam;
    }

    public String getAwayTeam() {
        return awayTeam;
    }

    public void setAwayTeam(String awayTeam) {
        this.awayTeam = awayTeam;
    }

    public MatchVO(long matchTime, String homeTeam, String awayTeam, String homeTeamIcon, String awayTeamIcon,
                   Integer homeScore, Integer awayScore, Integer state, Integer stageId, Integer groupNum, Integer roundNum) {
        this.matchTime = matchTime;
        this.homeTeam = homeTeam;
        this.awayTeam = awayTeam;
        this.homeTeamIcon = homeTeamIcon;
        this.awayTeamIcon = awayTeamIcon;
        this.homeScore = homeScore;
        this.awayScore = awayScore;
        this.state = state;
        this.stageId = stageId;
    }

    public MatchVO() {
    }
}

==> customer-link-project-api-1.1.25-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app89420/vo/MatchVO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app89420.vo;

public class MatchVO {

    /**
     * 比赛时间
     */
    private long matchTime;

    /**
     * 主场球队
     */
    private String homeTeam;

    /**
     * 主场球队
     */
    private String homeTeamId;

    /**
     * 客场球队
     */
    private String awayTeam;

    /**
     * 客场球队
     */
    private String awayTeamId;

    /**
     * 主场国家图片
     */
    private String homeTeamIcon;

    /**
     * 客场国家图片
     */
    private String awayTeamIcon;

    /**
     * 主场分数
     */
    private Integer homeScore;

    /**
     * 客场分数
     */
    private Integer awayScore;

    /**
     * 比赛状态 0-未完赛 1-已完赛
     */
    private Integer state;

    /**
     * 阶段id
     * 50897 分组赛
     * 50898 1/8决赛
     * 50899 1/4決賽
     * 50900 半決賽
     * 50901 季軍賽
     * 50902 決賽
     */
    private Integer stageId;

    /**
     * 组数
     */
    private Integer groupNum;

    /**
     * 轮次数
     */
    private Integer roundNum;

    /**
     * 比赛id
     */
    private String matchId;

    public String getHomeTeamId() {
        return homeTeamId;
    }

    public void setHomeTeamId(String homeTeamId) {
        this.homeTeamId = homeTeamId;
    }

    public String getAwayTeamId() {
        return awayTeamId;
    }

    public void setAwayTeamId(String awayTeamId) {
        this.awayTeamId = awayTeamId;
    }

    public String getMatchId() {
        return matchId;
    }

    public void setMatchId(String matchId) {
        this.matchId = matchId;
    }

    public Integer getStageId() {
        return stageId;
    }

    public void setStageId(Integer stageId) {
        this.stageId = stageId;
    }

    public Integer getGroupNum() {
        return groupNum;
    }

    public void setGroupNum(Integer groupNum) {
        this.groupNum = groupNum;
    }

    public Integer getRoundNum() {
        return roundNum;
    }

    public void setRoundNum(Integer roundNum) {
        this.roundNum = roundNum;
    }

    public String getHomeTeamIcon() {
        return homeTeamIcon;
    }

    public void setHomeTeamIcon(String homeTeamIcon) {
        this.homeTeamIcon = homeTeamIcon;
    }

    public String getAwayTeamIcon() {
        return awayTeamIcon;
    }

    public void setAwayTeamIcon(String awayTeamIcon) {
        this.awayTeamIcon = awayTeamIcon;
    }

    public Integer getHomeScore() {
        return homeScore;
    }

    public void setHomeScore(Integer homeScore) {
        this.homeScore = homeScore;
    }

    public Integer getAwayScore() {
        return awayScore;
    }

    public void setAwayScore(Integer awayScore) {
        this.awayScore = awayScore;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public long getMatchTime() {
        return matchTime;
    }

    public void setMatchTime(long matchTime) {
        this.matchTime = matchTime;
    }

    public String getHomeTeam() {
        return homeTeam;
    }

    public void setHomeTeam(String homeTeam) {
        this.homeTeam = homeTeam;
    }

    public String getAwayTeam() {
        return awayTeam;
    }

    public void setAwayTeam(String awayTeam) {
        this.awayTeam = awayTeam;
    }

    public MatchVO(long matchTime, String homeTeam, String awayTeam, String homeTeamIcon, String awayTeamIcon,
                   Integer homeScore, Integer awayScore, Integer state, Integer stageId, Integer groupNum, Integer roundNum) {
        this.matchTime = matchTime;
        this.homeTeam = homeTeam;
        this.awayTeam = awayTeam;
        this.homeTeamIcon = homeTeamIcon;
        this.awayTeamIcon = awayTeamIcon;
        this.homeScore = homeScore;
        this.awayScore = awayScore;
        this.state = state;
        this.stageId = stageId;
    }

    public MatchVO() {
    }
}
